package application

import (
	"fmt"
	"net/http"

	"sirlab.de/go/knowyt/log"
	"sirlab.de/go/knowyt/user"
)

func (app *Application) RemovePlayer(usr *user.User, w http.ResponseWriter, r *http.Request) {
	gameRef := r.URL.Query().Get("g")
	gm, err := app.GetGameById(gameRef)
	if err != nil {
		w.WriteHeader(http.StatusNotFound)
		fmt.Fprintf(w, "game not found")
		return
	}

	if usr.GetGameId() != gameRef || !usr.IsGamemaster() {
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	}

	id := r.URL.Query().Get("id")
	deleteUser := app.users[id]
	if deleteUser.GetId() != id || deleteUser.GetGameId() != gm.GetId() {
		w.WriteHeader(http.StatusForbidden)
		log.Warn("couldn't find player %s in game %s\n", id, gm.GetId())
		fmt.Fprintf(w, "forbidden")
		return
	}
	if deleteUser.GetId() == usr.GetId() {
		w.WriteHeader(http.StatusForbidden)
		log.Warn("can't delete yourself\n")
		fmt.Fprintf(w, "forbidden")
		return
	}

	if err := deleteUser.DeleteUser(); err != nil {
		w.WriteHeader(http.StatusInternalServerError)
		log.ErrorLog(err)
		fmt.Fprintf(w, "internal server error")
		return
	}
	gm.RemovePlayer(deleteUser)
	delete(app.users, id)

	fmt.Fprintf(w, "ok")
}
